% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sparseSCA.R
\name{sparseSCA}
\alias{sparseSCA}
\title{Variable selection with Lasso and Group Lasso with a multi-start procedure.}
\usage{
sparseSCA(DATA, Jk, R, LASSO, GROUPLASSO, MaxIter, NRSTARTS, method)
}
\arguments{
\item{DATA}{A matrix, which contains the concatenated data with the same subjects from multiple blocks.}

\item{Jk}{A vector containing number of variables in the concatinated data matrix.}

\item{R}{Number of components (R>=2).}

\item{LASSO}{A Lasso tuning parameter.}

\item{GROUPLASSO}{A group Lasso tuning parameter.}

\item{MaxIter}{The maximum rounds of iterations. It should be a positive integer. The default value is 400.}

\item{NRSTARTS}{Multi-start procedure: The number of multi-starts. The default value is 20.}

\item{method}{"datablock" or "component". If \code{method="component"}, the algorithm treats each component across all blocks independently, and thus sparse Group Lasso 
is applied per component. If \code{method="datablock"}, the algorithm applies sparse Group Lasso on the entire concatenated data block altogether.
If \code{method} is missing, then the \code{"component"} method is used.}
}
\value{
\item{Pmatrix}{The best estimated component loading matrix (i.e., P), if multi-starts >= 2.}
\item{Tmatrix}{The best estimated component score matrix (i.e., T), if multi-starts >= 2.}
\item{Lossvec}{A list of vectors containing the loss in each iteration for each multi-start.}
}
\description{
Variable selection with Lasso and Group Lasso penalties to identify component and distinctive components. This algorithm incorporates
a multi-start procedure to deal with the possible existence of local minima.
}
\examples{
\dontrun{
DATA1 <- matrix(rnorm(50), nrow=5)
DATA2 <- matrix(rnorm(100), nrow=5) 
DATA <- cbind(DATA1, DATA2)
Jk <- c(10, 20) 
R <- 5 
LASSO <- 0.2 
GROUPLASSO <- 0.4 
MaxIter <- 400
results <- sparseSCA(DATA, Jk, R, LASSO, GROUPLASSO, 
                    MaxIter, NRSTARTS = 10, method = "datablock")

results$Pmatrix 
}
}
\references{
Friedman, J., Hastie, T., & Tibshirani, R. (2010). A note on the group lasso and a sparse group lasso. arXiv preprint arXiv:1001.0736.

Yuan, M., & Lin, Y. (2006). Model selection and estimation in regression with grouped variables. Journal of the Royal Statistical Society: Series B (Statistical Methodology), 68(1), 49-67.
}
